@@ -1,4 +1,4 @@
-__version__ = "1.1.0"
+__version__ = "1.1.1"
 
 import logging
 
@@ -16,6 +16,11 @@ try:
 except Exception as ex:
     logging.error(f"Unable to load auth: {ex}")
 
+try:
+    from . import serialization
+except Exception as ex:
+    logging.error(f"Unable to load serialization: {ex}")
+
 try:
     from . import insights
     from .insights import (
